# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v1/jobs.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v1/jobs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%insightproto/proto/jobs/v1/jobs.proto\x12\x1ainsightproto.proto.jobs.v1\x1a)insightproto/proto/common/v1/common.proto\"\xd4\x01\n\nJobMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12;\n\naether_job\x18\x03 \x01(\x0b\x32%.insightproto.proto.jobs.v1.AetherJobH\x00\x12=\n\x0binsight_job\x18\x04 \x01(\x0b\x32&.insightproto.proto.jobs.v1.InsightJobH\x00\x42\x05\n\x03job\"\xa8\x02\n\tAetherJob\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x07project\x18\x02 \x01(\x0b\x32+.insightproto.proto.jobs.v1.ProviderProject\x12\x15\n\rOperationType\x18\x03 \x01(\t\x12\x14\n\x07IssueId\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0c\x44iscussionId\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0eMergeRequestId\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05JobId\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06NoteId\x18\x08 \x01(\tH\x04\x88\x01\x01\x42\n\n\x08_IssueIdB\x0f\n\r_DiscussionIdB\x11\n\x0f_MergeRequestIdB\x08\n\x06_JobIdB\t\n\x07_NoteId\"c\n\x0fProviderProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x08provider\x18\x03 \x01(\x0b\x32$.insightproto.proto.jobs.v1.Provider\"&\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\"N\n\nInsightJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07trigger\x18\x02 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\"M\n\x07Trigger\x12\x34\n\x06source\x18\x01 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\x0c\n\x04text\x18\x02 \x01(\tB/Z-github.com/opentrace/insight-proto-go/jobs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v1.jobs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v1'
  _globals['_JOBMESSAGE']._serialized_start=113
  _globals['_JOBMESSAGE']._serialized_end=325
  _globals['_AETHERJOB']._serialized_start=328
  _globals['_AETHERJOB']._serialized_end=624
  _globals['_PROVIDERPROJECT']._serialized_start=626
  _globals['_PROVIDERPROJECT']._serialized_end=725
  _globals['_PROVIDER']._serialized_start=727
  _globals['_PROVIDER']._serialized_end=765
  _globals['_INSIGHTJOB']._serialized_start=767
  _globals['_INSIGHTJOB']._serialized_end=845
  _globals['_TRIGGER']._serialized_start=847
  _globals['_TRIGGER']._serialized_end=924
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import insightproto.proto.common.v1.common_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogEntry(google.protobuf.message.Message):
    """LogEntry represents a standardized log entry"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    level: builtins.str
    """the log entry level (info, debug, etc)"""
    message: builtins.str
    """the main log entry message"""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp of the log entry"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """any labels attached to the log"""

    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        level: builtins.str = ...,
        message: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["labels", b"labels", "level", b"level", "message", b"message", "timestamp", b"timestamp"]) -> None: ...

global___LogEntry = LogEntry

@typing.final
class Metadata(google.protobuf.message.Message):
    """Metadata contains information about the log response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_COUNT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    log_count: builtins.int
    """the number of logs returned"""
    @property
    def source(self) -> insightproto.proto.common.v1.common_pb2.Source:
        """the data source info"""

    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the start of the time frame"""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the end of the time frame"""

    def __init__(
        self,
        *,
        log_count: builtins.int = ...,
        source: insightproto.proto.common.v1.common_pb2.Source | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "source", b"source", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "log_count", b"log_count", "source", b"source", "start_time", b"start_time"]) -> None: ...

global___Metadata = Metadata

@typing.final
class LogResponse(google.protobuf.message.Message):
    """LogResponse contains standardized log response data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTRIES_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogEntry]:
        """the log entries"""

    @property
    def metadata(self) -> global___Metadata:
        """meta data about the logs"""

    def __init__(
        self,
        *,
        entries: collections.abc.Iterable[global___LogEntry] | None = ...,
        metadata: global___Metadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "metadata", b"metadata"]) -> None: ...

global___LogResponse = LogResponse

@typing.final
class LogRequest(google.protobuf.message.Message):
    """Log request message for querying logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ORG_FIELD_NUMBER: builtins.int
    query: builtins.str
    """the query to use"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the start of the time frame"""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the end of the time frame"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """the labels for the query"""

    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """the org info for the request"""

    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        query: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "org", b"org", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "labels", b"labels", "org", b"org", "query", b"query", "start_time", b"start_time"]) -> None: ...

global___LogRequest = LogRequest

@typing.final
class MultipleResponse(google.protobuf.message.Message):
    """MultipleResponse is a wrapper for returning multiple responses"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORG_FIELD_NUMBER: builtins.int
    RESPONSES_FIELD_NUMBER: builtins.int
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation:
        """the org info for the request"""

    @property
    def responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogResponse]:
        """Each configured data source would return a response"""

    def __init__(
        self,
        *,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        responses: collections.abc.Iterable[global___LogResponse] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["org", b"org", "responses", b"responses"]) -> None: ...

global___MultipleResponse = MultipleResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/results.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/results.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+insightproto/proto/results/v1/results.proto\x12\x1dinsightproto.proto.results.v1\x1a)insightproto/proto/common/v1/common.proto\"\xc7\x02\n\x13InvestigationResult\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12H\n\x10\x61lert_extraction\x18\x02 \x01(\x0b\x32..insightproto.proto.results.v1.AlertExtraction\x12>\n\x08timeline\x18\x03 \x03(\x0b\x32,.insightproto.proto.results.v1.TimelineEvent\x12\x12\n\nchecks_run\x18\x04 \x03(\t\x12=\n\nhypotheses\x18\x05 \x03(\x0b\x32).insightproto.proto.results.v1.Hypothesis\x12\x1a\n\x12primary_hypothesis\x18\x06 \x01(\t\"C\n\x0f\x41lertExtraction\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"{\n\rTimelineEvent\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x36\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32(.insightproto.proto.results.v1.EventData\"\x9b\x04\n\tEventData\x12\x15\n\x08username\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tsource_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x61\x63tion\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07success\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x15\n\x08hostname\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0cprocess_name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x10\n\x03pid\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0c\x63ommand_line\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x11\n\x04user\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0e\x64\x65stination_ip\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08protocol\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x1d\n\x10\x64\x65stination_port\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12\x17\n\nbytes_sent\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x14\n\x07\x63ommand\x18\x0e \x01(\tH\r\x88\x01\x01\x42\x0b\n\t_usernameB\x0c\n\n_source_ipB\t\n\x07_actionB\n\n\x08_successB\x0b\n\t_hostnameB\x0f\n\r_process_nameB\x06\n\x04_pidB\x0f\n\r_command_lineB\x07\n\x05_userB\x11\n\x0f_destination_ipB\x0b\n\t_protocolB\x13\n\x11_destination_portB\r\n\x0b_bytes_sentB\n\n\x08_command\"p\n\nHypothesis\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\x1b\n\x13supporting_evidence\x18\x03 \x03(\t\x12\x1c\n\x14timeline_correlation\x18\x04 \x03(\tB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.results_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_INVESTIGATIONRESULT']._serialized_start=122
  _globals['_INVESTIGATIONRESULT']._serialized_end=449
  _globals['_ALERTEXTRACTION']._serialized_start=451
  _globals['_ALERTEXTRACTION']._serialized_end=518
  _globals['_TIMELINEEVENT']._serialized_start=520
  _globals['_TIMELINEEVENT']._serialized_end=643
  _globals['_EVENTDATA']._serialized_start=646
  _globals['_EVENTDATA']._serialized_end=1185
  _globals['_HYPOTHESIS']._serialized_start=1187
  _globals['_HYPOTHESIS']._serialized_end=1299
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import insightproto.proto.common.v1.common_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InvestigationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORG_FIELD_NUMBER: builtins.int
    ALERT_EXTRACTION_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    CHECKS_RUN_FIELD_NUMBER: builtins.int
    HYPOTHESES_FIELD_NUMBER: builtins.int
    PRIMARY_HYPOTHESIS_FIELD_NUMBER: builtins.int
    primary_hypothesis: builtins.str
    @property
    def org(self) -> insightproto.proto.common.v1.common_pb2.Organisation: ...
    @property
    def alert_extraction(self) -> global___AlertExtraction: ...
    @property
    def timeline(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TimelineEvent]: ...
    @property
    def checks_run(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def hypotheses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Hypothesis]: ...
    def __init__(
        self,
        *,
        org: insightproto.proto.common.v1.common_pb2.Organisation | None = ...,
        alert_extraction: global___AlertExtraction | None = ...,
        timeline: collections.abc.Iterable[global___TimelineEvent] | None = ...,
        checks_run: collections.abc.Iterable[builtins.str] | None = ...,
        hypotheses: collections.abc.Iterable[global___Hypothesis] | None = ...,
        primary_hypothesis: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["alert_extraction", b"alert_extraction", "org", b"org"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alert_extraction", b"alert_extraction", "checks_run", b"checks_run", "hypotheses", b"hypotheses", "org", b"org", "primary_hypothesis", b"primary_hypothesis", "timeline", b"timeline"]) -> None: ...

global___InvestigationResult = InvestigationResult

@typing.final
class AlertExtraction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    timestamp: builtins.str
    summary: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        timestamp: builtins.str = ...,
        summary: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["summary", b"summary", "tags", b"tags", "timestamp", b"timestamp"]) -> None: ...

global___AlertExtraction = AlertExtraction

@typing.final
class TimelineEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    timestamp: builtins.str
    summary: builtins.str
    source: builtins.str
    @property
    def data(self) -> global___EventData: ...
    def __init__(
        self,
        *,
        timestamp: builtins.str = ...,
        summary: builtins.str = ...,
        source: builtins.str = ...,
        data: global___EventData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "source", b"source", "summary", b"summary", "timestamp", b"timestamp"]) -> None: ...

global___TimelineEvent = TimelineEvent

@typing.final
class EventData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    SOURCE_IP_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    PROCESS_NAME_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    COMMAND_LINE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DESTINATION_IP_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_FIELD_NUMBER: builtins.int
    BYTES_SENT_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    username: builtins.str
    source_ip: builtins.str
    action: builtins.str
    success: builtins.bool
    hostname: builtins.str
    process_name: builtins.str
    pid: builtins.int
    command_line: builtins.str
    user: builtins.str
    destination_ip: builtins.str
    protocol: builtins.str
    destination_port: builtins.int
    bytes_sent: builtins.int
    command: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        source_ip: builtins.str | None = ...,
        action: builtins.str | None = ...,
        success: builtins.bool | None = ...,
        hostname: builtins.str | None = ...,
        process_name: builtins.str | None = ...,
        pid: builtins.int | None = ...,
        command_line: builtins.str | None = ...,
        user: builtins.str | None = ...,
        destination_ip: builtins.str | None = ...,
        protocol: builtins.str | None = ...,
        destination_port: builtins.int | None = ...,
        bytes_sent: builtins.int | None = ...,
        command: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_action", b"_action", "_bytes_sent", b"_bytes_sent", "_command", b"_command", "_command_line", b"_command_line", "_destination_ip", b"_destination_ip", "_destination_port", b"_destination_port", "_hostname", b"_hostname", "_pid", b"_pid", "_process_name", b"_process_name", "_protocol", b"_protocol", "_source_ip", b"_source_ip", "_success", b"_success", "_user", b"_user", "_username", b"_username", "action", b"action", "bytes_sent", b"bytes_sent", "command", b"command", "command_line", b"command_line", "destination_ip", b"destination_ip", "destination_port", b"destination_port", "hostname", b"hostname", "pid", b"pid", "process_name", b"process_name", "protocol", b"protocol", "source_ip", b"source_ip", "success", b"success", "user", b"user", "username", b"username"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_action", b"_action", "_bytes_sent", b"_bytes_sent", "_command", b"_command", "_command_line", b"_command_line", "_destination_ip", b"_destination_ip", "_destination_port", b"_destination_port", "_hostname", b"_hostname", "_pid", b"_pid", "_process_name", b"_process_name", "_protocol", b"_protocol", "_source_ip", b"_source_ip", "_success", b"_success", "_user", b"_user", "_username", b"_username", "action", b"action", "bytes_sent", b"bytes_sent", "command", b"command", "command_line", b"command_line", "destination_ip", b"destination_ip", "destination_port", b"destination_port", "hostname", b"hostname", "pid", b"pid", "process_name", b"process_name", "protocol", b"protocol", "source_ip", b"source_ip", "success", b"success", "user", b"user", "username", b"username"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_action", b"_action"]) -> typing.Literal["action"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_bytes_sent", b"_bytes_sent"]) -> typing.Literal["bytes_sent"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_command", b"_command"]) -> typing.Literal["command"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_command_line", b"_command_line"]) -> typing.Literal["command_line"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_destination_ip", b"_destination_ip"]) -> typing.Literal["destination_ip"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_destination_port", b"_destination_port"]) -> typing.Literal["destination_port"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_hostname", b"_hostname"]) -> typing.Literal["hostname"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_pid", b"_pid"]) -> typing.Literal["pid"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_process_name", b"_process_name"]) -> typing.Literal["process_name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_protocol", b"_protocol"]) -> typing.Literal["protocol"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_source_ip", b"_source_ip"]) -> typing.Literal["source_ip"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_success", b"_success"]) -> typing.Literal["success"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_user", b"_user"]) -> typing.Literal["user"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_username", b"_username"]) -> typing.Literal["username"] | None: ...

global___EventData = EventData

@typing.final
class Hypothesis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    SUPPORTING_EVIDENCE_FIELD_NUMBER: builtins.int
    TIMELINE_CORRELATION_FIELD_NUMBER: builtins.int
    description: builtins.str
    confidence: builtins.float
    @property
    def supporting_evidence(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timeline_correlation(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        confidence: builtins.float = ...,
        supporting_evidence: collections.abc.Iterable[builtins.str] | None = ...,
        timeline_correlation: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "description", b"description", "supporting_evidence", b"supporting_evidence", "timeline_correlation", b"timeline_correlation"]) -> None: ...

global___Hypothesis = Hypothesis
